#!/bin/ksh
############################################################ {COPYRIGHT-TOP} ###
# IBM Confidential
# OCO Source Materials
# Tivoli Common Reporting Infrastructure
# 5724-T69
#
# Copyright IBM Corp. 2010
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
############################################################ {COPYRIGHT-END} ##
SCRIPT=`basename $0`
LOGFILE=/tmp/IBM_Tivoli_Common_Reporting_2.1.1_InterimFix_14.log
ERROR=0
DEFAULT_INSTALLATION_DIR=/opt/IBM/tivoli/tipv2Components/TCRComponent

cd `dirname $0`
HERE=`pwd`
cd - 1>/dev/null 2>&1

Usage()
{
   [[ " $NV_TRACE " = +(* all *|* install *) || -n $DEBUG ]] && set -x
   echo "Usage:  $SCRIPT  -i | -r [TCR_INSTALLATION_DIR]"
   echo ""
   echo "where:"
   echo "  -i        Install InterimFix."
   echo "  -r        Rollback (uninstall) InterimFix."
   echo "  [TCR_INSTALLATION_DIR] (example: $DEFAULT_INSTALLATION_DIR)"
   echo ""
   exit 0
}

echo --------------------------------------------------------------------------
echo IBM Tivoli Common Reporting 2.1.1.0 InterimFix 14
echo --------------------------------------------------------------------------

case "$1" in
'-i')
DO="update";;
'-r')
DO="undo";;
esac
TIP_INSTALL="$2"

if [ -z "$DO" ]; then
   Usage
   exit 1
fi

if [  "$TIP_INSTALL" = "" ]; then
   Usage
   exit 1
fi

cd $TIP_INSTALL
TIP_INSTALL=`pwd`
cd - 1>/dev/null 2>&1

printf "Setting up Deployment Engine environment.\n"

if [ -x /var/ibm/common/acsi/setenv.sh ]; then
   . /var/ibm/common/acsi/setenv.sh
elif [ -x ~/.acsi_$LOGNAME/setenv.sh ]; then
   . ~/.acsi_$LOGNAME/setenv.sh
else
   echo "$SCRIPT: Unable to set up Deployment Engine environment for this user."
   exit 1
fi

# check if the directory exists (in case of dispatcher, there is no tipv2) and then proceed...
if [ -d $TIP_INSTALL/../../tipv2 ]; then
	if [ -f $TIP_INSTALL/../../tipv2/profiles/TIPProfile/logs/server1/server1.pid ]; then
	   if [ $DO = "update" ]; then
	      printf "Stop Tivoli Common Reporting server before installing the InterimFix.\n"
	   else
	      printf "Stop Tivoli Common Reporting server before uninstalling the InterimFix.\n"
	   fi
	   exit 1
	fi
fi

if [ $DO = "update" ]; then
   options="-u true"
   printf "Installing TCR-2110-0014...\n"
else
   printf "Uninstalling TCR-2110-0014...\n"
fi

cd $HERE/TCR-2110-0014/META-INF
manageIU.sh -o $DO -r $TIP_INSTALL -p packagedIU.xml $options 1>>$LOGFILE 2>&1
ReturnCode=$?

if [ $ReturnCode -ne 0 ]; then
   ERROR=3
   if [ $DO = "update" ]; then
      printf "InterimFix installation failed.\n"
   else
      printf "InterimFix uninstallation failed.\n"
   fi
   printf "Check details in $LOGFILE\n"
fi

cd - 1>/dev/null 2>&1

if [ $ERROR = 0 ]; then
   if [ $DO = "update" ]; then
      printf "InterimFix installed successfully.\n"
   else
      printf "InterimFix uninstalled successfully.\n"
   fi
   printf "Now start Tivoli Common Reporting server.\n"
fi

exit $ERROR
